@@ -1,16 +1,15 @@
 import os
 import re
 import string
-import sys
 from configparser import ConfigParser
 from pathlib import Path
 from typing import Optional
 
 import click
+from git import Repo, InvalidGitRepositoryError, NoSuchPathError
 from halo import Halo
 from jira import JIRA, JIRAError
 from unidecode import unidecode
-from git import Repo, InvalidGitRepositoryError, NoSuchPathError, GitCommandError
 
 
 class JIRACredentials:
@@ -124,14 +123,26 @@ def get_branch_name_from_issue(issue_id: str) -> str:
     return Utils.issue_title_to_branch_name(issue_id, title, issue_type)
 
 
-def create_branch(branch_name, push=False, source_branch='develop'):
+def create_branch(branch_name, push=False, target: Path = Path.cwd(), source_branch='develop'):
     try:
-        repo = Repo(Path.cwd())
+        repo = Repo(target)
         #  check if dirty
         if repo.is_dirty():
             click.secho("Current working dir not clean, please commit or stash your changes first", fg='red')
             exit(1)
 
+        # check if develop exists otherwise switch to master otherwise switch to main
+        for branch in [source_branch, 'master', 'main']:
+            spinner = Halo(text=f'Checking if source branch {branch} exists...', spinner='dots')
+            spinner.start()
+            if check_if_branch_exists(repo, branch):
+                source_branch = branch
+                click.secho(f'YES', fg='red')
+                spinner.stop()
+                break
+            else:
+                click.secho(f'NO', fg='red')
+
         #  check if a branch by this name already exists locally
         click.secho('Checking if branch already exists on local repository...')
         if check_if_branch_is_local(repo, branch_name):
@@ -142,7 +153,7 @@ def create_branch(branch_name, push=False, source_branch='develop'):
         #  check if a branch by this name already exists on remote
         spinner = Halo(text='Checking if branch already exists on remote repository...', spinner='dots')
         spinner.start()
-        if check_if_branch_name_available(repo, branch_name):
+        if not check_if_branch_exists(repo, branch_name):
             click.secho('Branch name IS available', fg='green')
         else:
             click.secho('A remote branch by that name already exists... aborting', fg='green')
@@ -150,7 +161,7 @@ def create_branch(branch_name, push=False, source_branch='develop'):
         spinner.stop()
 
         #  we're good to go
-        #  create MR branch from latest develop
+        #  create MR branch from latest develop or master
         try:
             spinner = Halo(text='Fetching all remote branches', spinner='dots')
             spinner.start()
@@ -161,19 +172,21 @@ def create_branch(branch_name, push=False, source_branch='develop'):
             print(err)
             spinner.stop()
         try:
-            source = f'origin/{source_branch}'
-            spinner = Halo(text=f'Creating local branch {branch_name} from {source}', spinner='dots')
+            spinner = Halo(text=f'Creating local branch {branch_name} from {source_branch}', spinner='dots')
             spinner.start()
-            repo.git.execute(['git', 'checkout', '-b', branch_name, source])
+            repo.git.execute(['git', 'checkout', source_branch])
+            repo.git.execute(['git', 'pull'])
+            repo.git.execute(['git', 'branch', branch_name])
             spinner.stop()
             click.secho(f'Created local branch {branch_name}', fg='green')
+            switch_to_branch(repo, branch_name)
         except Exception as err:
             click.secho('Failed to create local branch...')
             print(err)
             spinner.stop()
 
         # setting remote tracking branch
-        upstream_branch_command = ['git', 'push', '-u', f'origin/{branch_name}']
+        upstream_branch_command = ['git', 'push', '-u', 'origin', f'{branch_name}']
         if push:
             repo.git.execute(upstream_branch_command)
         else:
@@ -200,11 +213,11 @@ def check_if_branch_is_local(repo, branch_name) -> bool:
     return True
 
 
-def check_if_branch_name_available(repo, branch_name) -> bool:
+def check_if_branch_exists(repo, branch_name) -> bool:
     remote_branch = repo.git.execute(['git', 'ls-remote', '--heads', 'origin', branch_name])
     if remote_branch:
-        return False
-    return True
+        return True
+    return False
 
 
 def switch_to_branch(repo, branch_name):
@@ -250,7 +263,9 @@ class Utils:
               help='Generates the branch name and prints it, no actual branch will be created (default is False)')
 @click.option('-p', '--push', is_flag=True, default=False,
               help='Push newly created branch to remote (default is False)')
-def cli(issue_id_or_url, name_only, push):
+@click.option('-t', '--target', type=Path, default=Path.cwd(),
+              help='Target repository (default is current directory)')
+def cli(issue_id_or_url, name_only, push, target: Path):
     """Simple program that takes a JIRA issue ID and creates a new local and tracking remote branch"""
 
     if '/' in issue_id_or_url:
@@ -268,10 +283,10 @@ def cli(issue_id_or_url, name_only, push):
         click.secho('BRANCH NAME: '.ljust(len(branch_name), '#'))
         click.echo(branch_name)
         click.secho(''.rjust(len(branch_name), '#'))
-        if not check_if_branch_name_available(Repo(Path.cwd()), branch_name):
+        if check_if_branch_exists(Repo(target), branch_name):
             click.secho(f'WARNING: a remote branch by that name already exists', fg='red')
     else:
-        create_branch(branch_name, push)
+        create_branch(branch_name, push, target)
 
 
 if __name__ == '__main__':
